==> jc-1.4.0.tar.gz: java/util/zip/InflaterDynHeader.h <==
// class java.util.zip.InflaterDynHeader

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b0fe35a23cbc6a4d java_util_zip_InflaterDynHeader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_zip_InflaterDynHeader_H_
#define _JC_java_util_zip_InflaterDynHeader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_InflaterHuffmanTree$object;
struct _jc_java_util_zip_StreamManipulator$object;

// Typedefs
typedef struct _jc_java_util_zip_InflaterDynHeader$sub_refs	_jc_java_util_zip_InflaterDynHeader$sub_refs;
typedef struct _jc_java_util_zip_InflaterDynHeader$sub_nonrefs	_jc_java_util_zip_InflaterDynHeader$sub_nonrefs;
typedef struct _jc_java_util_zip_InflaterDynHeader$refs	_jc_java_util_zip_InflaterDynHeader$refs;
typedef struct _jc_java_util_zip_InflaterDynHeader$nonrefs	_jc_java_util_zip_InflaterDynHeader$nonrefs;
typedef struct _jc_java_util_zip_InflaterDynHeader$object	_jc_java_util_zip_InflaterDynHeader$object;

typedef struct _jc_java_util_zip_InflaterDynHeader$fields_struct	_jc_java_util_zip_InflaterDynHeader$fields_struct;
typedef const struct _jc_java_util_zip_InflaterDynHeader$vmethods	_jc_java_util_zip_InflaterDynHeader$vmethods;
typedef const struct _jc_java_util_zip_InflaterDynHeader$vtable	_jc_java_util_zip_InflaterDynHeader$vtable;
typedef const struct _jc_java_util_zip_InflaterDynHeader$vtype	_jc_java_util_zip_InflaterDynHeader$vtype;

// Class fields structure
struct _jc_java_util_zip_InflaterDynHeader$fields_struct {
	_jc_int_array	*BL__5fORDER;
	_jc_int_array	*repBits;
	_jc_int_array	*repMin;
	jint	BLLENS;
	jint	BLNUM;
	jint	DNUM;
	jint	LENS;
	jint	LNUM;
	jint	REPS;
};
extern _jc_java_util_zip_InflaterDynHeader$fields_struct _jc_java_util_zip_InflaterDynHeader$class_fields;

// Constructors
extern void _jc_java_util_zip_InflaterDynHeader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *);

// Virtual methods
extern struct _jc_java_util_zip_InflaterHuffmanTree$object *_jc_java_util_zip_InflaterDynHeader$method$buildDistTree$d1848eff47d63b42(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *);
extern struct _jc_java_util_zip_InflaterHuffmanTree$object *_jc_java_util_zip_InflaterDynHeader$method$buildLitLenTree$d88a9e54f118d914(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *);
extern jboolean _jc_java_util_zip_InflaterDynHeader$method$decode$972eba01ec5cb09c(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *, struct _jc_java_util_zip_StreamManipulator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_InflaterDynHeader$method_info$buildDistTree$d1848eff47d63b42;
extern _jc_method _jc_java_util_zip_InflaterDynHeader$method_info$buildLitLenTree$d88a9e54f118d914;
extern _jc_method _jc_java_util_zip_InflaterDynHeader$method_info$decode$972eba01ec5cb09c;

// Static methods
extern void _jc_java_util_zip_InflaterDynHeader$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_util_zip_InflaterDynHeader$vmethods {
	struct _jc_java_util_zip_InflaterHuffmanTree$object	*(*buildDistTree$d1848eff47d63b42)(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *);
	struct _jc_java_util_zip_InflaterHuffmanTree$object	*(*buildLitLenTree$d88a9e54f118d914)(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *);
	jboolean	(*decode$972eba01ec5cb09c)(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *, struct _jc_java_util_zip_StreamManipulator$object *);
};

// Vtable
struct _jc_java_util_zip_InflaterDynHeader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_InflaterDynHeader$vmethods	java_util_zip_InflaterDynHeader;
};

// Vtype
struct _jc_java_util_zip_InflaterDynHeader$vtype {
	_jc_type			type;
	_jc_java_util_zip_InflaterDynHeader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_InflaterDynHeader$sub_refs {
	_jc_byte_array	*blLens;
	_jc_byte_array	*litdistLens;
	struct _jc_java_util_zip_InflaterHuffmanTree$object	*blTree;
};

// Reference instance fields (object)
struct _jc_java_util_zip_InflaterDynHeader$refs {
    _jc_java_util_zip_InflaterDynHeader$sub_refs	java_util_zip_InflaterDynHeader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_InflaterDynHeader$sub_nonrefs {
	jint	mode;
	jint	lnum;
	jint	dnum;
	jint	blnum;
	jint	num;
	jint	repSymbol;
	jbyte	lastLen;
	jint	ptr;
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_InflaterDynHeader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_InflaterDynHeader$sub_nonrefs	java_util_zip_InflaterDynHeader;
};

// Object instance structure
struct _jc_java_util_zip_InflaterDynHeader$object {
	_jc_java_util_zip_InflaterDynHeader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_InflaterDynHeader$vtype	*vtype;
	_jc_java_util_zip_InflaterDynHeader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_InflaterDynHeader$vtype _jc_java_util_zip_InflaterDynHeader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_InflaterDynHeader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_InflaterDynHeader$class_object;

#endif	/* _JC_java_util_zip_InflaterDynHeader_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/InflaterDynHeader.h <==
// class java.util.zip.InflaterDynHeader

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b0fe35a23cbc6a4d java_util_zip_InflaterDynHeader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_zip_InflaterDynHeader_H_
#define _JC_java_util_zip_InflaterDynHeader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_zip_InflaterHuffmanTree$object;
struct _jc_java_util_zip_StreamManipulator$object;

// Typedefs
typedef struct _jc_java_util_zip_InflaterDynHeader$sub_refs	_jc_java_util_zip_InflaterDynHeader$sub_refs;
typedef struct _jc_java_util_zip_InflaterDynHeader$sub_nonrefs	_jc_java_util_zip_InflaterDynHeader$sub_nonrefs;
typedef struct _jc_java_util_zip_InflaterDynHeader$refs	_jc_java_util_zip_InflaterDynHeader$refs;
typedef struct _jc_java_util_zip_InflaterDynHeader$nonrefs	_jc_java_util_zip_InflaterDynHeader$nonrefs;
typedef struct _jc_java_util_zip_InflaterDynHeader$object	_jc_java_util_zip_InflaterDynHeader$object;

typedef struct _jc_java_util_zip_InflaterDynHeader$fields_struct	_jc_java_util_zip_InflaterDynHeader$fields_struct;
typedef const struct _jc_java_util_zip_InflaterDynHeader$vmethods	_jc_java_util_zip_InflaterDynHeader$vmethods;
typedef const struct _jc_java_util_zip_InflaterDynHeader$vtable	_jc_java_util_zip_InflaterDynHeader$vtable;
typedef const struct _jc_java_util_zip_InflaterDynHeader$vtype	_jc_java_util_zip_InflaterDynHeader$vtype;

// Class fields structure
struct _jc_java_util_zip_InflaterDynHeader$fields_struct {
	_jc_int_array	*BL__5fORDER;
	_jc_int_array	*repBits;
	_jc_int_array	*repMin;
	jint	BLLENS;
	jint	BLNUM;
	jint	DNUM;
	jint	LENS;
	jint	LNUM;
	jint	REPS;
};
extern _jc_java_util_zip_InflaterDynHeader$fields_struct _jc_java_util_zip_InflaterDynHeader$class_fields;

// Constructors
extern void _jc_java_util_zip_InflaterDynHeader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_zip_InflaterHuffmanTree$object *_jc_java_util_zip_InflaterDynHeader$method$buildDistTree$d1848eff47d63b42(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_zip_InflaterHuffmanTree$object *_jc_java_util_zip_InflaterDynHeader$method$buildLitLenTree$d88a9e54f118d914(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_util_zip_InflaterDynHeader$method$decode$972eba01ec5cb09c(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *, struct _jc_java_util_zip_StreamManipulator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_zip_InflaterDynHeader$method_info$buildDistTree$d1848eff47d63b42;
extern _jc_method _jc_java_util_zip_InflaterDynHeader$method_info$buildLitLenTree$d88a9e54f118d914;
extern _jc_method _jc_java_util_zip_InflaterDynHeader$method_info$decode$972eba01ec5cb09c;

// Static methods
extern void _jc_java_util_zip_InflaterDynHeader$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_zip_InflaterDynHeader$vmethods {
	struct _jc_java_util_zip_InflaterHuffmanTree$object	*(*buildDistTree$d1848eff47d63b42)(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_zip_InflaterHuffmanTree$object	*(*buildLitLenTree$d88a9e54f118d914)(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *) _JC_JCNI_ATTR;
	jboolean	(*decode$972eba01ec5cb09c)(_jc_env *, struct _jc_java_util_zip_InflaterDynHeader$object *, struct _jc_java_util_zip_StreamManipulator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_zip_InflaterDynHeader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_InflaterDynHeader$vmethods	java_util_zip_InflaterDynHeader;
};

// Vtype
struct _jc_java_util_zip_InflaterDynHeader$vtype {
	_jc_type			type;
	_jc_java_util_zip_InflaterDynHeader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_InflaterDynHeader$sub_refs {
	_jc_byte_array	*blLens;
	_jc_byte_array	*litdistLens;
	struct _jc_java_util_zip_InflaterHuffmanTree$object	*blTree;
};

// Reference instance fields (object)
struct _jc_java_util_zip_InflaterDynHeader$refs {
    _jc_java_util_zip_InflaterDynHeader$sub_refs	java_util_zip_InflaterDynHeader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_InflaterDynHeader$sub_nonrefs {
	jint	mode;
	jint	lnum;
	jint	dnum;
	jint	blnum;
	jint	num;
	jint	repSymbol;
	jbyte	lastLen;
	jint	ptr;
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_InflaterDynHeader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_InflaterDynHeader$sub_nonrefs	java_util_zip_InflaterDynHeader;
};

// Object instance structure
struct _jc_java_util_zip_InflaterDynHeader$object {
	_jc_java_util_zip_InflaterDynHeader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_InflaterDynHeader$vtype	*vtype;
	_jc_java_util_zip_InflaterDynHeader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_InflaterDynHeader$vtype _jc_java_util_zip_InflaterDynHeader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_InflaterDynHeader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_InflaterDynHeader$class_object;

#endif	/* _JC_java_util_zip_InflaterDynHeader_H_ */
